#ifdef GL_ES
precision lowp float;
#endif

varying vec4 v_fragmentColor;
varying vec2 v_texCoord;
uniform sampler2D u_texture;
uniform float u_outlineWidth;
uniform float u_pixelWidth;
uniform vec4 u_outlineColor;
uniform vec4 u_fillColor;

float getAlpha(vec2 offset)
{
    vec2 modifiedCoord = v_texCoord + offset;
    
    if (modifiedCoord.x < 0.0
        || modifiedCoord.x > 1.0
        || modifiedCoord.y < 0.0
        || modifiedCoord.y > 1.0) {
        return 0.0;
    }
    return texture2D(u_texture, modifiedCoord).a;
}

void main()
{
    if (getAlpha(vec2(0,0)) != 0.0) {
        if (getAlpha(vec2(-u_outlineWidth, 0)) == 0.0 || getAlpha(vec2(u_outlineWidth, 0)) == 0.0 || getAlpha(vec2(0, u_outlineWidth)) == 0.0 || getAlpha(vec2(0, -u_outlineWidth)) == 0.0) {
            gl_FragColor = u_outlineColor;
        } else {
            gl_FragColor = texture2D(u_texture, v_texCoord);
        }
    } else {
        float combinedAlpha = 0.0;
        const float glowDepth = 5.0;
        for (float i = 1.0; i <= glowDepth; i++) {
            combinedAlpha += getAlpha(vec2(-u_outlineWidth * i, 0));
            combinedAlpha += getAlpha(vec2(u_outlineWidth * i, 0));
            combinedAlpha += getAlpha(vec2(0, u_outlineWidth * i));
            combinedAlpha += getAlpha(vec2(0, -u_outlineWidth * i));
        }
        combinedAlpha = combinedAlpha / (4.0 * glowDepth);
        gl_FragColor = u_outlineColor * combinedAlpha;
    }
}

